@@ -6,7 +6,6 @@
     Necessary libraries
 """
 import argparse
-import datetime
 import os
 
 import torch.optim as optim
@@ -16,13 +15,14 @@ from torchvision.transforms import Compose
 from neuralnets.data.datasets import UnlabeledVolumeDataset
 from neuralnets.networks.bvae import BVAE
 from neuralnets.util.augmentation import *
+from neuralnets.util.io import print_frm
 from neuralnets.util.losses import get_loss_function
 from neuralnets.util.tools import set_seed
 
 """
     Parse all the arguments
 """
-print('[%s] Parsing arguments' % (datetime.datetime.now()))
+print_frm('Parsing arguments')
 parser = argparse.ArgumentParser()
 
 # logging parameters
@@ -69,7 +69,7 @@ set_seed(args.seed)
 """
     Setup logging directory
 """
-print('[%s] Setting up log directories' % (datetime.datetime.now()))
+print_frm('Setting up log directories')
 if not os.path.exists(args.log_dir):
     os.mkdir(args.log_dir)
 
@@ -77,7 +77,7 @@ if not os.path.exists(args.log_dir):
     Load the data
 """
 input_shape = (1, args.input_size[0], args.input_size[1])
-print('[%s] Loading data' % (datetime.datetime.now()))
+print_frm('Loading data')
 augmenter = Compose([ToFloatTensor(device=args.device), Rotate90(), FlipX(prob=0.5), FlipY(prob=0.5),
                      ContrastAdjust(adj=0.1),
                      RandomDeformation_2D(input_shape[1:], grid_size=(64, 64), sigma=0.01, device=args.device)])
@@ -91,7 +91,7 @@ test_loader = DataLoader(test, batch_size=args.train_batch_size)
 """
     Build the network
 """
-print('[%s] Building the network' % (datetime.datetime.now()))
+print_frm('Building the network')
 net = BVAE(beta=args.beta, input_size=args.input_size, bottleneck_dim=args.bottleneck, feature_maps=args.fm,
            levels=args.levels, dropout_enc=args.dropout, dropout_dec=args.dropout, norm=args.norm,
            activation=args.activation)
@@ -99,15 +99,15 @@ net = BVAE(beta=args.beta, input_size=args.input_size, bottleneck_dim=args.bottl
 """
     Setup optimization for training
 """
-print('[%s] Setting up optimization for training' % (datetime.datetime.now()))
+print_frm('Setting up optimization for training')
 optimizer = optim.Adam(net.parameters(), lr=args.lr)
 scheduler = optim.lr_scheduler.StepLR(optimizer, step_size=args.step_size, gamma=args.gamma)
 
 """
     Train the network
 """
-print('[%s] Starting training' % (datetime.datetime.now()))
+print_frm('Starting training')
 net.train_net(train_loader, test_loader, loss_rec_fn, loss_kl_fn, optimizer, args.epochs, scheduler=scheduler,
               augmenter=augmenter, print_stats=args.print_stats, log_dir=args.log_dir, device=args.device)
 
-print('[%s] Finished!' % (datetime.datetime.now()))
+print_frm('Finished!')
